@@ -22,9 +22,11 @@
 
 #include "common.h"
 
-#if ANIMAL_HAVE_BAD_GLUT
+/* The following will be activated in case we use GLUT in the future */
+/*#if ANIMAL_HAVE_BAD_GLUT*/
    /* Workaround for NVIDIA GLUT libs.  
     * We define some stubs because these functions are irrelevant */
+/*
    void glXGetFBConfigAttribSGIX() {}
    void glXQueryChannelDeltasSGIX() {}
    void glXChannelRectSyncSGIX() {}
@@ -33,3 +35,4 @@
    void glXGetFBConfigFromVisualSGIX() {}
    void glXBindChannelToWindowSGIX() {}
 #endif
+*/
