@@ -28,7 +28,7 @@
  *    - Improved code documentation
  *    - More descriptive variable names
  *
- * $Revision: 1.3 $ $Date: 2004/04/22 22:42:02 $
+ * $Revision: 1.4 $ $Date: 2004/05/27 06:42:07 $
  *
  * ANIMAL - ANIMAL IMage Processing LibrarY
  * Copyright (C) 2002,2003  Ricardo Fabbri <rfabbri@if.sc.usp.br>
@@ -272,10 +272,10 @@ cuisenaire_initmasterlist(ImgPUInt32 *im, puint32 *max, puint32 **ssq)
 
 
    /* lookup table for squares */
-   dummy = gan_malloc_array(puint32, 4*M + 1);
+   dummy = animal_malloc_array(puint32, 4*M + 1);
            if (!dummy) {
-              gan_err_flush_trace();                                
-              gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"");  
+              animal_err_flush_trace();                                
+              animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"");  
               return false;                                          
            }
 
@@ -289,10 +289,10 @@ cuisenaire_initmasterlist(ImgPUInt32 *im, puint32 *max, puint32 **ssq)
 
    /* list allocation */
    maxd = r*r + c*c + 1;
-   master_list = gan_malloc_array(ptrgrid, maxd + 2*c);  /* @@@ why 2*c ?? */
+   master_list = animal_malloc_array(ptrgrid, maxd + 2*c);  /* @@@ why 2*c ?? */
                  if (!master_list) {
-                      gan_err_flush_trace();                                
-                      gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"");  
+                      animal_err_flush_trace();                                
+                      animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"");  
                       return false;                                          
                  }
    /* initialization */
@@ -627,7 +627,7 @@ edt_cuisenaire_pNxN(ImgPUInt32 *im, puint32 max, puint32 *sq)
    imdata = DATA(im);
 
    if(max > min_error[NUMBER_OF_MASKS-1]) {
-      /* @@@ use gandalf */
+      /* @@@ use animal */
       fprintf(stderr,"Warning: perfect map not guaranteed \n");
       min_error[NUMBER_OF_MASKS-1]=max+1;
    }
@@ -715,7 +715,7 @@ edt_cuisenaire_poNxN(ImgPUInt32 *im, puint32 maxdist, puint32 *sq)
    imdata = DATA(im);
 
    if(maxdist > min_error[NUMBER_OF_MASKS-1]) {
-      /* @@@ use gandalf */
+      /* @@@ use animal */
       fprintf(stderr,"Warning: perfect map not guaranteed \n");
       min_error[NUMBER_OF_MASKS-1]=maxdist+1;
    }
@@ -843,10 +843,10 @@ cuisenaire_addtolist(int x, int y, int dx, int dy, puint32 val)
    tmp = master_list[val];
 
    if (tmp == NULL) {  /* bucket is empty */
-      tmp = gan_malloc_object(grid);
+      tmp = animal_malloc_object(grid);
           if (!tmp) {
-             gan_err_flush_trace();                              
-             gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"");
+             animal_err_flush_trace();                              
+             animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"");
              return false;                                        
           }
       cnt = tmp->cnt = 0;
@@ -854,10 +854,10 @@ cuisenaire_addtolist(int x, int y, int dx, int dy, puint32 val)
       master_list[val] = tmp;
    } 
    else if ( (cnt = tmp->cnt) == CHUNK_SIZE) {  /* chunk is full */
-      tmp = gan_malloc_object(grid);
+      tmp = animal_malloc_object(grid);
           if (!tmp) {
-             gan_err_flush_trace();                              
-             gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"");
+             animal_err_flush_trace();                              
+             animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"");
              return false;                                        
           }
       cnt = tmp->cnt = 0;
@@ -916,12 +916,12 @@ smallest_error_location(nhood *N, puint32 *Derr_p,
 
    Derr = PUINT32_MAX;
 
-   GAN_MALLOC_ARRAY(test, bool, N->n, fname, false);
-//   GAN_MALLOC_ARRAY(dprod, int, N->n, fname, false);
+   ANIMAL_MALLOC_ARRAY(test, bool, N->n, fname, false);
+//   ANIMAL_MALLOC_ARRAY(dprod, int, N->n, fname, false);
 
    dpx = (start_dpx == 0) ? 1 : start_dpx;
 
-   assert(dpx > start_dpy);
+   assert((puint32)dpx > start_dpy);
 
    do {
       for (dpy = start_dpy; dpy <= dpx; ++dpy) {
@@ -1011,7 +1011,7 @@ bool closest_non_propagating_pixel (
 
    nh = square_nhood(n);
    if (!nh) {
-      gan_err_register(fname, GAN_ERROR_FAILURE,"");  
+      animal_err_register(fname, ANIMAL_ERROR_FAILURE,"");  
       return false;                                          
    }
 
