@@ -3,7 +3,7 @@
  *
  * D I S T A N C E   T R A N S F O R M   R O U T I N E S
  *
- * $Revision: 1.6 $ $Date: 2004/04/22 20:34:53 $
+ * $Revision: 1.8 $ $Date: 2004/05/15 21:53:59 $
  *
  * ANIMAL - ANIMAL IMage Processing LibrarY
  * Copyright (C) 2002,2003  Ricardo Fabbri <rfabbri@if.sc.usp.br>
@@ -74,6 +74,53 @@ bool edt_lz_vertical(ImgPUInt32 *im),
  * 
  *----------------------------------------------------------------------------*/
 
+bool
+distance_transform_ip(ImgPUInt32 *cost, dt_algorithm alg)
+{
+   char *fname="distance_transform_ip";
+   bool stat=true;
+
+   assert(cost->isbinary);
+   if (alg == DT_LOTUFO_ZAMPIROLLI)
+      stat = edt_lz(cost);
+   else if (alg == DT_MAURER2003)
+    stat = edt_maurer2003(cost);
+   else if (alg == DT_CUISENAIRE_PMN_1999)
+    stat = edt_cuisenaire_pmn(cost);
+   else if (alg == DT_CUISENAIRE_PMON_1999)
+    stat = edt_cuisenaire_pmon(cost);
+   else if (alg == DT_CUISENAIRE_PSN4_1999)
+    stat = edt_cuisenaire_psn4(cost);
+   else if (alg == DT_CUISENAIRE_PSN8_1999)
+    stat = edt_cuisenaire_psn8(cost);
+   else if (alg == DT_SAITO_1994)
+    stat = edt_saito(cost);
+   else if (alg == DT_EGGERS_1998)
+    stat = edt_eggers(cost);
+   else if (alg == DT_EXACT_DILATIONS)
+    stat = edt_exact_dilations(cost);
+   else if (alg == DT_BRUTE_FORCE)
+    stat = edt_brute_force(cost);
+   else if (alg == DT_BRUTE_FORCE_WITH_LIST)
+    stat = edt_brute_force_with_list(cost);
+   else if (alg == DT_IFT_8 || alg == DT_IFT) { /* IFT */
+      nhood *nh;
+      nh = get_8_nhood();
+      stat = edt_ift(cost, nh);
+      free_nhood(&nh);
+   } else if (alg == DT_IFT_4) { /* IFT */
+      nhood *nh;
+      nh = get_4_nhood();
+      stat = edt_ift(cost, nh);
+      free_nhood(&nh);
+   } else {
+      animal_err_register (fname, ANIMAL_ERROR_ILLEGAL_ARGUMENT,"argument must be a valid dt_algorithm enum constant"); 
+      return false;
+   }
+
+   return stat;
+}
+
 AnimalExport ImgPUInt32 *
 distance_transform(Img *bin, dt_algorithm alg)
 {
@@ -88,60 +135,15 @@ distance_transform(Img *bin, dt_algorithm alg)
 
    cost = new_img_puint32(r,c);
    if (!cost) {
-      gan_err_register(fname,GAN_ERROR_FAILURE,"");
+      animal_err_register(fname,ANIMAL_ERROR_FAILURE,"");
       return NULL;
    }
    cost->isbinary=true;
    for (i=0; i<(unsigned)r*c; i++)
       DATA(cost)[i] = DATA(bin)[i];
 
-   if (alg == DT_LOTUFO_ZAMPIROLLI) { 
-      stat = edt_lz(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_MAURER2003) {
-      stat = edt_maurer2003(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_CUISENAIRE_PMN_1999)  {
-      stat = edt_cuisenaire_pmn(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_CUISENAIRE_PMON_1999) {
-      stat = edt_cuisenaire_pmon(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_CUISENAIRE_PSN4_1999) {
-      stat = edt_cuisenaire_psn4(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_CUISENAIRE_PSN8_1999) {
-      stat = edt_cuisenaire_psn8(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_SAITO_1994) {
-      stat = edt_saito(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_EXACT_DILATIONS) {
-      stat = edt_exact_dilations(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_BRUTE_FORCE) {
-      stat = edt_brute_force(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_BRUTE_FORCE_WITH_LIST) {
-      stat = edt_brute_force_with_list(cost);
-      CHECK_RET_STATUS(NULL);
-   } else if (alg == DT_IFT_8 || alg == DT_IFT) { /* IFT */
-      nhood *nh;
-      nh = get_8_nhood();
-      stat = edt_ift(cost, nh);
-      CHECK_RET_STATUS(NULL);
-      free_nhood(&nh);
-   } else if (alg == DT_IFT_4) { /* IFT */
-      nhood *nh;
-      nh = get_4_nhood();
-      stat = edt_ift(cost, nh);
-      CHECK_RET_STATUS(NULL);
-      free_nhood(&nh);
-   } else {
-      gan_err_register (fname, GAN_ERROR_ILLEGAL_ARGUMENT,"argument must be a valid dt_algorithm enum constant"); 
-      imfree_puint32(&cost);
-      return NULL;
-   }
+   stat = distance_transform_ip(cost, alg);
+   CHECK_RET_STATUS(NULL);
 
    return cost; 
 }
@@ -195,11 +197,11 @@ edt_lz (ImgPUInt32 *im)
          DATA(im)[i] = infty;
 
    if ( !edt_lz_vertical(im) ) {
-      gan_err_register ("edt_lz_horizontal", GAN_ERROR_FAILURE,""); 
+      animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,""); 
       return false;
    }
    if ( !edt_lz_horizontal(im) ) {
-      gan_err_register ("edt_lz_horizontal", GAN_ERROR_FAILURE,""); 
+      animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,""); 
       return false;
    }
 
@@ -273,22 +275,22 @@ edt_lz_horizontal(ImgPUInt32 *im)
    nc = im->cols;
    Eq = siq_new(nc);   
       if(!Eq) { /* report error using Gandalf */;
-         gan_err_register ("edt_lz_horizontal", GAN_ERROR_FAILURE,"Demanding new Eq"); 
+         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Eq"); 
          return false;
       }
    Eq2 = siq_new(nc);
       if(!Eq2) { 
-         gan_err_register ("edt_lz_horizontal", GAN_ERROR_FAILURE,"Demanding new Eq2"); 
+         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Eq2"); 
          return false;
       }
    Wq = siq_new(nc);
       if(!Wq) { 
-         gan_err_register ("edt_lz_horizontal", GAN_ERROR_FAILURE,"Demanding new Wq"); 
+         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Wq"); 
          return false;
       }
    Wq2 = siq_new(nc);
       if(!Wq2) { 
-         gan_err_register ("edt_lz_horizontal", GAN_ERROR_FAILURE,"Demanding new Wq2"); 
+         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Wq2"); 
          return false;
       }
 
@@ -353,7 +355,7 @@ edt_lz_horizontal(ImgPUInt32 *im)
 
 
 
-/*----FUNCTION-------------------------------------------------------------------------
+/*----FUNCTION-----------------------------------------------------------------
  * 
  *  Description:  Calvin Maurer's EDT (Euclidean DistanceTransform): 
  *
@@ -364,15 +366,14 @@ edt_lz_horizontal(ImgPUInt32 *im)
  *    http://ltilib.sourceforge.net
  *  
  *  Distances are calculated only where pixels are equal to 1
- *  (aka "internal EDT").
  *
- * - PARAMETER -------------------------------------------------------------------------
+ * - PARAMETER ----------------------------------------------------------------
  *      Mode   Type             Name            Description
- * -------------------------------------------------------------------------------------
+ * ----------------------------------------------------------------------------
  *    in-out:  ImgPUInt32         im            binary image on input;
  *                                              grayscale on output, with
  *                                              squared distance transform.
- *-------------------------------------------------------------------------------------*/
+ *----------------------------------------------------------------------------*/
 
 AnimalExport bool
 edt_maurer2003(ImgPUInt32 *im)
@@ -396,11 +397,10 @@ edt_maurer2003(ImgPUInt32 *im)
    // Lotufo's 1D EDT is equivalent to Maurer's D1.
    // There is a remark in section 5 of Maurer's paper that says
    // D1 can be calculated using a propagation routine like this.
-   CHECK_RET_STATUS(false);;
+   CHECK_RET_STATUS(false);
 
-   // Maurer's 2D EDT from 1D EDT
    stat = edt_maurer_2D_from_1D(im);      
-   CHECK_RET_STATUS(false);;
+   CHECK_RET_STATUS(false);
 
    im->isbinary = false;
    return true;
@@ -417,16 +417,16 @@ edt_maurer_2D_from_1D(ImgPUInt32 *im)
    // Call voronoi_edt_2D for every row.
    // OBS: g and h are internal to maurer_voronoi_edt_2d and are
    // pre-allocated here for efficiency.
-   g = gan_malloc_array(int, im->cols);
+   g = animal_malloc_array(int, im->cols);
        if (!g) {
-          gan_err_flush_trace();                                
-          gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"");  
+          animal_err_flush_trace();                                
+          animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"");  
           return false;                                          
        }                                                        
-   h = gan_malloc_array(int, im->cols);
+   h = animal_malloc_array(int, im->cols);
        if (!h) {
-          gan_err_flush_trace();                                
-          gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"");  
+          animal_err_flush_trace();                                
+          animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"");  
           return false;                                          
        }                                                        
 
@@ -489,7 +489,7 @@ maurer_voronoi_edt_2D(ImgPUInt32 *im, int j1, int *g, int *h)
 
 inline bool 
 remove_edt(int du, int dv, int dw, 
-                      int u,  int v,  int w)
+           int u,  int v,  int w)
 {
     // 11 integer expressions
     int a = v - u,
@@ -534,7 +534,7 @@ edt_exact_dilations(ImgPUInt32 *image)
 
    sedr = grow_sedr(maxrad);
    if (!sedr) {
-      gan_err_register (fname, GAN_ERROR_FAILURE,"");
+      animal_err_register (fname, ANIMAL_ERROR_FAILURE,"");
       return false;                                    
    }
 
@@ -691,15 +691,15 @@ edt_ift(ImgPUInt32 *image, nhood *adj)
 
    Dx = (puint32 *) calloc(n,sizeof(puint32));
    if (!Dx) {
-      gan_err_flush_trace();                                
-      gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"Variable Dx");  
+      animal_err_flush_trace();                                
+      animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"Variable Dx");  
       return false;                                          
    }
 
    Dy = (puint32 *) calloc(n,sizeof(puint32));
    if (!Dy) {
-      gan_err_flush_trace();                                
-      gan_err_register(fname, GAN_ERROR_MALLOC_FAILED,"Variable Dx");  
+      animal_err_flush_trace();                                
+      animal_err_register(fname, ANIMAL_ERROR_MALLOC_FAILED,"Variable Dx");  
       return false;                                          
    }
 
@@ -713,7 +713,7 @@ edt_ift(ImgPUInt32 *image, nhood *adj)
                           2*((r-1)*max_vert + (c-1)*max_hor);
    pq = new_pqueue(nbuck,n,img);
 	if (!pq) {
-      gan_err_register (fname, GAN_ERROR_FAILURE,""); 
+      animal_err_register (fname, ANIMAL_ERROR_FAILURE,""); 
 		return false;
 	}
 
@@ -766,7 +766,7 @@ edt_ift(ImgPUInt32 *image, nhood *adj)
    while (!is_empty_pqueue(pq)) {
       p = remove_pqueue(pq);
 		if (p == NIL) {
-			gan_err_register (fname, GAN_ERROR_FAILURE,""); 
+			animal_err_register (fname, ANIMAL_ERROR_FAILURE,""); 
 			return false;
 		}
       px = p % c;
@@ -855,7 +855,7 @@ edt_brute_force_with_list (ImgPUInt32 *im)
 
    c = im->cols;
    n = im->rows*c;
-   GAN_MALLOC_ARRAY(list, puint32, n, fname, false);
+   ANIMAL_MALLOC_ARRAY(list, puint32, n, fname, false);
 
    n_ones = 0;
    ptr_zeros = n-1;
@@ -895,31 +895,42 @@ edt_brute_force_with_list (ImgPUInt32 *im)
  * based on two independent implementations by O. Cuisenaire
  * and J. C. Torelli.
  *
- * T. Saito and J.I. Toriwaki, "New algorithms for Euclidean distance 
- * transformations of an n-dimensional digitised picture with applications",
- * Pattern Recognition, 27(11), pp. 1551-1565, 1994
+ * PAPER
+ *    T. Saito and J.I. Toriwaki, "New algorithms for Euclidean distance 
+ *    transformations of an n-dimensional digitised picture with applications",
+ *    Pattern Recognition, 27(11), pp. 1551-1565, 1994
+ *
+ * A nice overview of Saito's method may be found at:
+ *    Chapter 2 of "Distance transformations: fast algorithms and applications 
+ *    to medical image processing", Olivier Cuisenaire's Ph.D. Thesis, October 
+ *    1999, Universit catholique de Louvain, Belgium.
+ * 
  *  
  */
 AnimalExport bool
 edt_saito(ImgPUInt32 *im)
 {
    char *fname="edt_saito";
-   unsigned i,j,r,c,n,l,a,b,m, buffer,
+   unsigned i,j,r,c,n,l,a,b,m, buffer, nsqr, diag1,
             *ptstart, *ptend, *sq, *df2, *buff, *pt, *npt;
    puint32 *map;
 
 
+
+   assert(im->isbinary);
    map = DATA(im);
    r = im->rows; c = im->cols;
-   n = r*c;
+   n = r*c; 
+   diag1 = ceilf(hypotf(r-1,c-1))-1;   // this is >= the diagonal minus 1
 
    /* Cuisenaire's idea: a LUT with precomputed i*i */
-   GAN_MALLOC_ARRAY(sq, unsigned, 2*r+2, fname, false);
-   for (i=0; i<2*r+2; ++i)
+   nsqr = 2*(diag1 + 1);   /* was: 2*r + 2 in Cuisenaire's code */
+   ANIMAL_MALLOC_ARRAY(sq, unsigned, nsqr, fname, false);
+   for (i=0; i<nsqr; ++i)
       sq[i] = i*i;
 
    /* buff stores the current column in step 2 */
-   GAN_MALLOC_ARRAY(buff, unsigned, r, fname, false);
+   ANIMAL_MALLOC_ARRAY(buff, unsigned, r, fname, false);
 
    /*-- Step 1 --*/
    for (j=0; j<r; ++j) {
@@ -927,7 +938,7 @@ edt_saito(ImgPUInt32 *im)
       ptend = ptstart + c;
 
       /* forward scan */
-      df2 = sq + r;
+      df2 = sq + diag1;  /* the paper: df2 = sq + r, not large enough */
       for (pt=ptstart; pt < ptend; ++pt)
          if (*pt)
             *pt = *(++df2);
@@ -935,7 +946,7 @@ edt_saito(ImgPUInt32 *im)
             df2 = sq;
 
       /* backward scan */
-      df2 = sq + r;
+      df2 = sq + diag1;  /* the paper: df2 = sq + r, not large enough */
       for (--pt; pt != (unsigned *)(ptstart-1); --pt)
          if (*pt) {
             if (*pt > *(++df2))
@@ -961,17 +972,17 @@ edt_saito(ImgPUInt32 *im)
             --a;
          if (buff[j] > buffer+1) {
             b = (buff[j] - buffer-1) / 2;
-            if (j+b > r-1)
+            if (j+b+1 > r)
                b = r-1 -j;
 
-            npt = pt + a*r;
+            npt = pt + a*c;
             for (l=a; l<=b; ++l) {
                m = buffer + sq[l+1];
                if (buff[j+l] <= m)
-                  break;
+                  break;   /* go to next column j */
                if (m < *npt)
                   *npt = m;
-               npt += r;
+               npt += c;
             }
             a = b;
          } else
@@ -985,21 +996,21 @@ edt_saito(ImgPUInt32 *im)
       buffer = buff[r-1];
 
       for (j=r-2;  j != (unsigned)-1;  --j, pt-=c) {
-         if (a > 0)
+         if (a != 0)
             --a;
          if (buff[j] > buffer+1) {
             b = (buff[j] - buffer-1) / 2;
-            if (j-b > r-1)
+            if (j < b)
                b = j;
 
-            npt = pt - a*r;
+            npt = pt - a*c;
             for (l=a; l<=b; ++l) {
                m = buffer + sq[l+1];
-               if (buff[j+l] <= m)
-                  break;
+               if (buff[j-l] <= m)
+                  break;   /* go to next column j */
                if (m < *npt)
                   *npt = m;
-               npt -= r;
+               npt -= c;
             }
             a = b;
          } else
