@@ -461,7 +461,7 @@ imfill(Img *img, point *seed, pixval paintval, pixval maskval, nhood *nh)
    if (nh == DEFAULT_NHOOD) {
       nh = get_4_nhood();   // default useful for filling 8-conn. contours
       if (!nh) {
-         gan_err_register (fname, GAN_ERROR_FAILURE,""); 
+         animal_err_register (fname, ANIMAL_ERROR_FAILURE,""); 
          return false;
       }
       nh_alloc=true;
@@ -472,7 +472,7 @@ imfill(Img *img, point *seed, pixval paintval, pixval maskval, nhood *nh)
    do {
       cp = ptpop(&current);
          if (!cp) {
-            gan_err_register (fname, GAN_ERROR_FAILURE,""); 
+            animal_err_register (fname, ANIMAL_ERROR_FAILURE,""); 
             return false;
          }
 
@@ -506,7 +506,7 @@ imfill_puint32(ImgPUInt32 *img, point *seed, puint32 paintval, puint32 maskval,
    if (nh == DEFAULT_NHOOD) {
       nh = get_4_nhood();   // default useful for filling 8-conn. contours
       if (!nh) {
-         gan_err_register (fname, GAN_ERROR_FAILURE,""); 
+         animal_err_register (fname, ANIMAL_ERROR_FAILURE,""); 
          return false;
       }
       nh_alloc=true;
@@ -517,7 +517,7 @@ imfill_puint32(ImgPUInt32 *img, point *seed, puint32 paintval, puint32 maskval,
    do {
       cp = ptpop(&current);
          if (!cp) {
-            gan_err_register (fname, GAN_ERROR_FAILURE,""); 
+            animal_err_register (fname, ANIMAL_ERROR_FAILURE,""); 
             return false;
          }
 
@@ -569,7 +569,7 @@ label_components_np(ImgPUInt32 *img, nhood *nh)
             seed.y = i; seed.x = j;
             stat = imfill_puint32(img, &seed, l++, FG, nh);
                if (!stat) {
-                  gan_err_register ("label_components_ip_np", GAN_ERROR_FAILURE,""); 
+                  animal_err_register ("label_components_ip_np", ANIMAL_ERROR_FAILURE,""); 
                   return -1;
                }
          }
