@@ -12,7 +12,7 @@ main (int argc, char *argv[])
    Img *im;
    ImgPUInt32 *img;
 
-   gan_err_set_trace(GAN_ERR_TRACE_ON);
+   animal_err_set_trace(ANIMAL_ERR_TRACE_ON);
 
    if (--argc >=1)
       strncpy(filename, argv[1],99);
@@ -38,7 +38,7 @@ main (int argc, char *argv[])
 //   img = distance_transform(im, DT_EXACT_DILATIONS);
    img = distance_transform(im, DT_BRUTE_FORCE);
    if (!img)
-      gan_err_default_reporter();
+      animal_err_default_reporter();
 
 //   for (i=0; i<im->rows*im->cols; i++) {
 //      if (DATA(img)[i] == 0)
@@ -51,6 +51,6 @@ main (int argc, char *argv[])
 
    imfree(&im);
    imfree_puint32(&img);
-   gan_heap_report(NULL);
+   animal_heap_report(NULL);
 	return 0;
 }
