@@ -10,7 +10,7 @@ main (int argc, char *argv[])
    int stat;
    nhood *nh;
 
-   gan_err_set_trace(GAN_ERR_TRACE_ON);
+   animal_err_set_trace(ANIMAL_ERR_TRACE_ON);
 
 
    if (--argc >=1)
@@ -25,7 +25,7 @@ main (int argc, char *argv[])
    nh = get_8_nhood();
    stat=label_components_np(lbl,nh);
       if(stat < 0)
-         gan_err_default_reporter();
+         animal_err_default_reporter();
 
    printf("Number of regions: %d\n",stat);
 
@@ -34,6 +34,6 @@ main (int argc, char *argv[])
    free_nhood(&nh);
    imfree(&im);
    imfree_puint32(&lbl);
-   gan_heap_report(NULL);
+   animal_heap_report(NULL);
 	return 0;
 }
