@@ -7,7 +7,7 @@ main()
    int data[]={11,3,69,0,0,0,0,0,0,0};
    SIQueue *q;
 
-   gan_err_set_trace( GAN_ERR_TRACE_ON);
+   animal_err_set_trace( ANIMAL_ERR_TRACE_ON);
 
    /*
     *  Test integer linked list
@@ -32,6 +32,6 @@ main()
    siq_print(q);
    siq_free(&q);
 
-   gan_heap_report(NULL);
+   animal_heap_report(NULL);
    return 0;
 }
