@@ -9,7 +9,7 @@ main(int argc, char *argv[])
    annotated_skl *skl;
    int thresh=25, i;
 
-   gan_err_set_trace(GAN_ERR_TRACE_ON);
+   animal_err_set_trace(ANIMAL_ERR_TRACE_ON);
 
    if (--argc >=1)
       strncpy(filename, argv[1],99);
@@ -27,7 +27,7 @@ main(int argc, char *argv[])
 
    skl = msskl(img,INTERIOR,SKL_IFT);
    if (!skl)
-      gan_err_default_reporter();
+      animal_err_default_reporter();
 
    overpose = new_img(img->rows,img->cols);
    for (i=0; i<img->rows*img->cols; i++)
@@ -41,12 +41,13 @@ main(int argc, char *argv[])
       overpose->data[i] = (skl->skl->data[i] >= (puint32) thresh) + tmp->data[i];
 
    imshow(overpose,0,-1);
+   imwrite(overpose,"teste.png",true);
 
    free_ann_skl(&skl);
    imfree(&img);
    imfree(&tmp);
    imfree(&overpose);
 
-   gan_heap_report(NULL);
+   animal_heap_report(NULL);
    return 0;
 }
