@@ -9,7 +9,7 @@ main (int argc, char *argv[])
    Img *im;
    ImgPUInt32 *regions;
 
-   gan_err_set_trace(GAN_ERR_TRACE_ON);
+   animal_err_set_trace(ANIMAL_ERR_TRACE_ON);
 
    if (--argc >=1)
       strncpy(filename, argv[1],99);
@@ -25,6 +25,6 @@ main (int argc, char *argv[])
    imfree(&im);
    free_nhood(&nh);
    imfree_puint32(&regions);
-   gan_heap_report(NULL);
+   animal_heap_report(NULL);
 	return 0;
 }
